==> ELAN-3_3_0-src.zip: ELAN-3.3.0-src/src/java/mpi/eudico/client/annotator/commands/SaveCommand.java <==
/*
 * File:     SaveCommand.java
 * Project:  MPI Linguistic Application
 * Date:     12 December 2007
 *
 * Copyright (C) 2001-2008  Max Planck Institute for Psycholinguistics
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package mpi.eudico.client.annotator.commands;

import mpi.eudico.client.annotator.ElanLocale;

import mpi.eudico.server.corpora.clom.Transcription;
import mpi.eudico.server.corpora.clom.TranscriptionStore;

import java.io.IOException;

import java.util.Vector;

import javax.swing.JOptionPane;


/**
 * DOCUMENT ME!
 *
 * @author Hennie Brugman
 */
public class SaveCommand implements Command {
    private String commandName;

    /**
     * Creates a new SaveCommand instance
     *
     * @param name DOCUMENT ME!
     */
    public SaveCommand(String name) {
        commandName = name;
    }

    /**
     * DOCUMENT ME!
     *
     * @param receiver DOCUMENT ME!
     * @param arguments DOCUMENT ME!
     */
    public void execute(Object receiver, Object[] arguments) {
        Transcription tr = (Transcription) receiver;

        TranscriptionStore eafTranscriptionStore = (TranscriptionStore) arguments[0];

        // for the moment, don't deal with visible tiers
        try {
            eafTranscriptionStore.storeTranscription(tr, null, new Vector(),
                null, TranscriptionStore.EAF);
            tr.setUnchanged();
        } catch (IOException ioe) {
            JOptionPane.showMessageDialog(null,
                
            //ElanLocale.getString("ExportDialog.Message.Error") + "\n" +
            "Unable to save the transcription file: " + "(" + ioe.getMessage() +
                ")", ElanLocale.getString("Message.Error"),
                JOptionPane.ERROR_MESSAGE);
        }
    }

    /**
     * DOCUMENT ME!
     *
     * @return DOCUMENT ME!
     */
    public String getName() {
        return commandName;
    }
}

==> ELAN-3_8_1-src.zip: ELAN-3.8.1-src/src/java/mpi/eudico/client/annotator/commands/SaveCommand.java <==
/*
 * File:     SaveCommand.java
 * Project:  MPI Linguistic Application
 * Date:     25 August 2009
 *
 * Copyright (C) 2001-2009  Max Planck Institute for Psycholinguistics
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package mpi.eudico.client.annotator.commands;

import mpi.eudico.client.annotator.ElanLocale;

import mpi.eudico.server.corpora.clom.Transcription;
import mpi.eudico.server.corpora.clom.TranscriptionStore;

import java.io.IOException;

import java.util.Vector;

import javax.swing.JOptionPane;


/**
 * DOCUMENT ME!
 *
 * @author Hennie Brugman
 */
public class SaveCommand implements Command {
    private String commandName;

    /**
     * Creates a new SaveCommand instance
     *
     * @param name DOCUMENT ME!
     */
    public SaveCommand(String name) {
        commandName = name;
    }

    /**
     * DOCUMENT ME!
     *
     * @param receiver DOCUMENT ME!
     * @param arguments DOCUMENT ME!
     */
    public void execute(Object receiver, Object[] arguments) {
        Transcription tr = (Transcription) receiver;

        TranscriptionStore eafTranscriptionStore = (TranscriptionStore) arguments[0];

        // for the moment, don't deal with visible tiers
        try {
            eafTranscriptionStore.storeTranscription(tr, null, new Vector(),
                null, TranscriptionStore.EAF);
            tr.setUnchanged();
        } catch (IOException ioe) {
            JOptionPane.showMessageDialog(ELANCommandFactory.getRootFrame(tr),
                
            //ElanLocale.getString("ExportDialog.Message.Error") + "\n" +
            "Unable to save the transcription file: " + "(" + ioe.getMessage() +
                ")", ElanLocale.getString("Message.Error"),
                JOptionPane.ERROR_MESSAGE);
        }
    }

    /**
     * DOCUMENT ME!
     *
     * @return DOCUMENT ME!
     */
    public String getName() {
        return commandName;
    }
}
